function [X,distMin] = CirclePacking(n);

% References:
% [1] Packing of circles in the unit circle (05B40, 52C17)
%     http://hydra.nat.uni-magdeburg.de/packing/cci/
%     Data downloaded and converted on April 15, 2009.

% Check parameters
if ~isposintscalar(n) || n <= 0
   error('Number of points must be a positive integer');
elseif n > 200
   error('No data available for packings of %d circles', n);
end

% Construct filename
prefix     = mfilepath(mfilename('fullpath'));
prefixData = [prefix,'..',filesep,'data',filesep];
filename   = [prefixData,'CirclePackings.mat'];
data       = load(filename);

% Get packing
X = data.packings{n};

% Compute minimum distance
distMin = norm(X(:,1)-X(:,2),2);
for i=1:n
   for j=i+1:n
      dist = norm(X(:,i)-X(:,j),2);
      if dist < distMin, distMin = dist; end;
   end
end

return


% ---------------------------------------------------------------------------------
% Conversion script
% ---------------------------------------------------------------------------------
% 1. Download all_coords.tar.gz from http://hydra.nat.uni-magdeburg.de/packing/cci/
% 2. Unpack file
% 3. Run code below
% 4. Clean up all .txt and .gz files
% ---------------------------------------------------------------------------------
packings = {};
for i=1:200
   s = load(sprintf('cci%d.txt',i));
   packings{i} = s(:,2:3)';
end
save(filename,'packings');


