function FigDish(exportFlag)

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get filename prefix
prefix      = mfilepath(mfilename('fullpath'));
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];

% Set up parameters
l      = 1;
theta  = pi * 60 / 180;
lambda = 2;
x0     = -1;
y0     = 1.2;

% Initialize figure
figure(1); clf; gca; hold on;
xlim([-4,4]); ylim([0,5]);
set(gca,'DataAspectRatio',[1,1,1]);

% Draw base
plot(x0+[-0.4,0,0.4,-0.4],[0,y0,0,0],'k-');
plot(x0,y0,'k.');

% Plot lines
for alpha = linspace(-1.4*l,1.4*l,6)
   delta = solveDelta(l,alpha);
   x = [alpha,alpha,0];
   y = [l+15,l-delta,l];
   plot(x0+cos(theta)*y-sin(theta)*x, ...
        y0+sin(theta)*y+cos(theta)*x,'m--');
end
plot(x0+cos(theta)*[l,l+15], ...
     y0+sin(theta)*[l,l+15],'b-');

% Compute dish
alpha = linspace(-1.5*l,1.5*l,201);
delta = zeros(size(alpha));
for i=1:length(alpha)
   delta(i) = l-solveDelta(l,alpha(i));
end

% Plot dish
h = plot(x0+cos(theta)*delta-sin(theta)*alpha, ...
         y0+sin(theta)*delta+cos(theta)*alpha,'k-');
plot(x0+cos(theta)*l, ...
     y0+sin(theta)*l,'k*');
set(h,'LineWidth',2);

for i=0.2:lambda:15
   x = x0+cos(theta)*(l+i);
   y = y0+sin(theta)*(l+i);
   plot(x+[-sin(theta),0,sin(theta)]*100, ...
        y+[+cos(theta),0,-cos(theta)]*100,'b--');
end

axis off

if exportFlag == 1
   ExportFigurePDF(prefixFig,'FigDish.pdf');
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,'FigDish.eps');
end


% -------------------------------------------------------------
function delta = solveDelta(l,alpha)
% -------------------------------------------------------------
% Solve delta+sqrt(alpha^2+delta^2) = 2*l

delta = 2*l;
deltaPrev = 0;

while (abs(delta - deltaPrev) > 1e-6)
   f = delta + sqrt(alpha^2 + delta^2) - 2*l;
   g = 1 + delta/sqrt(alpha^2+delta^2);
   deltaPrev = delta;
   delta = delta - f / g;
end

