function FigPointArrangement(nAngles,exportFlag)
% FIGPOINTARRANGEMENT   Plot point arrangement on half-sphere

% Check export flag
if nargin < 1, nAngles = [200,400,500,600,1200]; end;
if nargin < 2, exportFlag = false; end;

% Get filename prefix
prefix      = mfilepath(mfilename('fullpath'));
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];



for i=1:length(nAngles)
   X = PointArrangement(3,nAngles(i),1e-5);
   idx = (X(3,:) >= 0); X = X(:,idx);

   figure(1); clf; gca; hold on; set(gca,'Fontsize',24);
   h = plot3(1.001*X(1,:),1.001*X(2,:),1.001*X(3,:),'b.');
   set(h,'MarkerSize',20);

   K = convhulln(X'); h = zeros(1,size(K,1));
   for j=1:size(K,1);
      h(j) = patch(X(1,K(j,:)),X(2,K(j,:)),X(3,K(j,:)),[1,0,0]);
   end
   hold off;
   xlim([-1,1]); ylim([-1,1]); zlim([0,1]);

   set(h,'FaceColor',[0.7,0.7,1],'EdgeColor','None');

   view(-60,45);
   camlight; grid on;

   if exportFlag == 1
      ExportFigurePNG(prefixFig,sprintf('FigPointArrangement_%d.png',nAngles(i)));
   elseif exportFlag == 2
      ExportFigureEPS(prefixFig,sprintf('FigPointArrangement_%d.eps',nAngles(i)));
   elseif i < length(nAngles)
      disp('Press <Return> to continue . . . ');
      pause;
   end

end

