function FigSignal(exportFlag)

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get filename prefix
prefix      = mfilepath(mfilename('fullpath'));
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];

% Set up parameters
theta  = pi * 60 / 180;
lambda = 3;

% Initialize figure
figure(1); clf; gca; hold on;

% Plot horizontal axis
h = plot([-3,7],[0,0],'k-');
set(h,'LineWidth',2);
plot([-2,0,2,4,6],0,'b*',0,0,'bo');

% Set limits
xlim([-3,7]); ylim([-1,5.5]);

% Plot main ray
h = plot([0,cos(theta)*20],[0,sin(theta)*20],'b-');
set(h,'LineWidth',2);

ct = cos(theta)*lambda;
st = sin(theta)*lambda;

% Add arc
angle = linspace(0,theta,50);
plot(cos(angle)*1.5,sin(angle)*1.5,'k-');
h = text(cos(theta/2)*1.7,sin(theta/2)*1.7,'$\theta$');
set(h,'HorizontalAlignment','left');

% Add incoming rays
offset = 0;
for i=offset:1:2*10/lambda
   x0 = ct*i;
   y0 = st*i;

   if y0 > 0
      plot(x0,y0,'b.');
   end

   x1 = x0-st*10; y1 = y0+ct*10;
   x2 = x0+st*10; y2 = y0-ct*10;

   if y1 < 0
      if y2 < 0, continue; end;
      x1 = x2 - (x2-x1) * y2 / (y2 - y1); y1 = 0;
   end

   if y2 < 0
      x2 = x2 - (x2-x1) * y2 / (y2 - y1); y2 = 0;
   end

   plot([x1,x2],[y1,y2],'b--');
end

x0 = ct*offset; x1 = ct*(offset+1); x2 = ct*(offset+0.5);
y0 = st*offset; y1 = st*(offset+1); y2 = st*(offset+0.5);

x0 = x0 - sin(theta) * 1;
x1 = x1 - sin(theta) * 1;
x2 = x2 - sin(theta) * 1.2;
y0 = y0 + cos(theta) * 1;
y1 = y1 + cos(theta) * 1;
y2 = y2 + cos(theta) * 1.2;

plot([x0,x1],[y0,y1],'k-');
h = text(x2,y2,'$\lambda$'); set(h,'HorizontalAlignment','center');


% Add sensor labels
for i=1:5
   h = text(i*2-4.2,-0.5,sprintf('$s_%d$',i));
   set(h,'HorizontalAlignment','left', ...
         'VerticalAlignment','baseline');
end

% Remove axes
axis off; set(gca,'DataAspectRatio',[1,1,1]);
hold off;

if exportFlag == 1
   ExportFigureLaTeXPDF(prefixFig, 'FigSignal.pdf','5cm');
elseif exportFlag == 2
   ExportFigureLaTeXEPS(prefixFig, 'FigSignal.eps','5cm');
end

