function GenerateFigure(figidx,exportFlag)
% GENERATEFIGURE   Generates plot from the paper
%
%    GENERATEFIGURE(FIGIDX,EXPORTFLAG) generates figure FIGIDX from the
%    paper, if it exists. The optional EXPORTFLAG parameter can be set to
%    export the plot to a PDF file. When FIGIDX = [], all figures are
%    generated.

% Create list of figures
figidc = {'2.1',...
          '3.2','3.3',...
          '5.1', ...
          '6.1','6.2','6.3','6.4','6.5',...
          '7.1','7.2','7.3'};

% Check parameters
if nargin < 1
   error('First parameter should be a figure index string, e.g. ''%s''', figidc{1});
end
if nargin < 2
   exportFlag = 0;
end

% Generate all figures if figidx is empty
if isempty(figidx)
   for i=1:length(figidc)
      GenerateFigure(figidc{i},exportFlag);
   end

   return;
end

% XFigure message
xfig = 'This figure was generated using XFig, please see %s in the fig directory\n';

% Generate specified figure
switch figidx

% ---------------------------------------------------------------------
% Section 2 - The Pareto curve
% ---------------------------------------------------------------------
case {'2.1',2.1}
   ExecuteScript('Misc','FigPareto(exportFlag);');
   pauseMessage(exportFlag);
   ExecuteScript('Misc','FigTauBar(exportFlag);');


% ---------------------------------------------------------------------
% Section 3 - Root finding with approximate functions and gradients
% ---------------------------------------------------------------------

case {'3.1',3.1}
   fprintf(xfig,'FigDualGapBound.fig');

case {'3.2',3.2}
   ExecuteScript('Misc','FigInfPolar(exportFlag);');

case {'3.3',3.3}
   ExecuteScript('Misc','RootConvergenceNonneg(exportFlag);');

% ---------------------------------------------------------------------
% Section 5 - Weighted basis pursuit denoise
% ---------------------------------------------------------------------

case {'5.1',5.1}
   ExecuteScript('WeightedBP','PlotBPDNWPaper(exportFlag);');


% ---------------------------------------------------------------------
% Section 6 - Group sparsity
% ---------------------------------------------------------------------

case {'6.1',6.1}
   ExecuteScript('DOA','FigDish(exportFlag);');
   pauseMessage(exportFlag);
   ExecuteScript('DOA','FigSignal(exportFlag);');

case {'6.2',6.2}
   ExecuteScript('DOA','FigBeamforming2D(exportFlag);');


case {'6.3',6.3}
   ExecuteScript('DOA','FigCirclePacking(80,exportFlag);');
   pauseMessage(exportFlag);
   ExecuteScript('DOA','FigPointArrangement(200,exportFlag);');
   pauseMessage(exportFlag);
   ExecuteScript('DOA','FigIterativelyRefine(1,exportFlag);');

case {'6.4',6.4}
   ExecuteScript('DOA','FigIterativelyRefine(3:10,exportFlag);');

case {'6.5',6.5}
   ExecuteScript('DOA','FigMMVGaussian2(20,1,exportFlag);');
   pauseMessage(exportFlag);
   ExecuteScript('DOA','FigMMVGaussian2(5,1,exportFlag);');

%case {'6.6',6.6}
%   ExecuteScript('DOA','FigMMVGaussian2(20,3,exportFlag);');
%   pauseMessage(exportFlag);
%   ExecuteScript('DOA','FigMMVGaussian2(5,3,exportFlag);');
%   pauseMessage(exportFlag);
%   ExecuteScript('DOA','FigMMVGaussian2(20,4,exportFlag);');

%case {'6.7',6.7}
%   ExecuteScript('DOA','FigMMVGaussian(20,2,exportFlag);');
%   pauseMessage(exportFlag);
%   ExecuteScript('DOA','FigMMVGaussian(5,2,exportFlag);');


% ---------------------------------------------------------------------
% Section 7 - Sign-constrained basis pursuit
% ---------------------------------------------------------------------

case {'7.1',7.1}
   ExecuteScript('MassSpectrography','FigSpectMixture(exportFlag);');


case {'7.2',7.2}
   ExecuteScript('Misc','FigBreakdownNonnegBP(exportFlag);');

case {'7.3',7.3}
   ExecuteScript('MassSpectrography','FigSpectPropane(exportFlag);');
                  



otherwise
   if ischar(figidx)
      fprintf('No code available to generate Figure %s\n',figidx);
   else
      fprintf('No code available to generate Figure %d\n',figidx);
   end
end


% Execude script in its local directory
function ExecuteScript(workdir,command)

   p = pwd;
   cd([mfilepath(mfilename('fullpath')),workdir]);
   try
      eval(command);
      cd(p);
   catch exception
      cd(p);
      rethrow(exception);
   end
end

function pauseMessage(exportFlag)
   if ~exportFlag
      fprintf('Press <return> to continue . . .\n');
      pause;
   end
end

function result = HaveCurvelab(msg)
   str = which('fdct_wrapping');
   result = ~isempty(str);
   if ~result
      fprintf('%s cannot be generated without Curvelab.\n',msg);
   end
end

end

