function info = GenerateSpectMixture
% Fields of info structure
% .dictionary    Dictionary of all spectrograms
% .idx           Index into dictionary of selected elements
% .mz            Mass/charge levels
% .A             Sparsity basis
% .b             Observed spectrogram (A*x0 + noise)
% .x0            Original coefficients
% .noise         Additive noise term

% ---------------------------------------------------------------------------
% Read dictionary
% ---------------------------------------------------------------------------
dictionary = IndexJCAMPDX;

% ---------------------------------------------------------------------------
% Get all entries with given weights and gather information about m/z values
% ---------------------------------------------------------------------------
mwLow = 65;
mwHigh = 85;

idx = zeros(size(dictionary,1),1); n = 0;
mz  = [];

for i=1:size(dictionary,1)
   if mwLow <= dictionary{i,3} && dictionary{i,3} <= mwHigh
      n      = n + 1;
      idx(n) = i;
      data   = dictionary{i,4};

      mz = [mz data(1,:)];
   end
end
idx = idx(1:n);
mz  = unique(mz);

% ---------------------------------------------------------------------------
% Construct matrix A
% ---------------------------------------------------------------------------
A = zeros(length(mz),n);

for i=1:length(idx)
   data = dictionary{idx(i),4};

   % Match mz values, assume mz in data is sorted
   k =1;
   for j=1:size(data,2)
      while mz(k) ~= data(1,j), k = k + 1; end;

      A(k,i) = data(2,j);
   end
end

% ---------------------------------------------------------------------------
% Construct random sparse mixture
% ---------------------------------------------------------------------------
rand('state',0); randn('state',0)
m     = 0.1+abs(randn(12,1)); % 18 for noiseless
m     = m / sum(m);
p     = randperm(n);
x0    = zeros(n,1); x0(p(1:length(m))) = m;
noise = randn(size(A,1),1)*0;
b     = A*x0 + noise;


% ---------------------------------------------------------------------------
% Create information structure
% ---------------------------------------------------------------------------
info = struct();
info.dictionary = dictionary;
info.idx        = idx;
info.mz         = mz;
info.A          = A;
info.b          = b;
info.x0         = x0;
info.noise      = noise;

