function FigBreakdownNonnegBP(exportFlag)

% Check arguments
if nargin < 1, exportFlag = 0; end;

% Get path information
prefix      = mfilepath(mfilename('fullpath'));
prefixCache = [prefix,'..',filesep,'cache',filesep];
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];

% Set plot parameters
fontsize = 20;

% Initialize
randn('state',0); randn('state',0);
A  = randn(40,80);

% Load precomputed data if available
filename = [prefixCache,'FigBreakdownNonnegative.mat'];

if exist(filename)
   data = load(filename);
   s1 = data.s1;
   s2 = data.s2;
   n  = data.i;   % number of random tests done
else
   s1 = zeros(40,1);
   s2 = zeros(40,1);
   n  = 0;
end

% Skip ahead random number generators
if n < 300
   for i=1:n
      for j=1:40
         p = randperm(80);
         p = randn(j,1);
      end      
   end   
end

% Solve remaining problems
for i=n+1:300
   for j=1:40
      x0= zeros(80,1);
      p = randperm(80);
      x0(p(1:j)) = abs(randn(j,1));
      x0 = x0 / norm(x0,2);
      b = A*x0;

      cvx_begin
         variable x1(80);
         minimize norm(x1,1);
         subject to
            A*x1 == b;
      cvx_end

      cvx_begin
         variable x2(80);
         minimize norm(x2,1);
         subject to
            A*x2 == b;
            x2   >= 0;
      cvx_end

      if norm(x1-x0,2) <= 1e-5, s1(j) = s1(j) + 1; end;
      if norm(x2-x0,2) <= 1e-5, s2(j) = s2(j) + 1; end;
   end

   plot(1:length(s1),s1,'r-',1:length(s2),s2,'b-'); pause(0.01);
   
   save(filename,'s1','s2','i');
end

% Done, plot results
h = plot(1:length(s1),s1/3,'r-',1:length(s2),s2/3,'b-');
set(h,'Linewidth',2);
set(gca,'Fontsize',fontsize);
xlabel('Number of nonzeros');
ylabel('Recovery (%)');
legend('BP','Nonnegative BP');

if exportFlag == 1
   ExportFigurePDF(prefixFig,'FigBreakdownNonnegBP.pdf');
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,'FigBreakdownNonnegBP.eps');
end
