function FigTauBar(exportFlag)

if nargin < 1, exportFlag = 0; end;
prefix      = mfilepath(mfilename('fullpath'));
prefixCache = [prefix,'..',filesep,'cache',filesep];
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];

% Initialize random number generator
randn('state',0);

% =====================================================================
% Plot I: Unreachable b
% =====================================================================

A = randn(60,50);
b = randn(60,1);

% Run homotopy algorithm
filename = [prefixCache,'FigTauBar1.mat'];
if ~exist(filename)
   % Set call-back option
   opts = as_setparms();
   opts.callback = @FigTauBarCallback;

   evalin('base','xHist = []; rHist = [];');
   [x,inform] = as_topy(A,b,[],opts);
   xHist = evalin('base','xHist'); rHist = evalin('base','rHist');

   % Patch history
   xHist(end) = 15; rHist(end) = rHist(end-1);

   % Save data
   save(filename,'xHist','rHist');
else
   data = load(filename);
   xHist = data.xHist;
   rHist = data.rHist;
end

% Plot result
figure(1); clf; gca; hold on; box on;
h = plot(xHist,rHist,'r-');
ht= plot([xHist(end-1),xHist(end-1)],[0,8],'b--');
set(gca,'Fontsize',24);
set(h,'Linewidth',3);
set(ht,'LineWidth',3);
set(gca,'XTick',[],'YTick',[]);
xlim([0,15]); ylim([0,8]);

if exportFlag == 1
   ExportFigurePDF(prefixFig,'FigTauBar1.pdf');
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,'FigTauBar1.eps');
end


% =====================================================================
% Plot II: Reachable b
% =====================================================================

A = randn(60,80).^3;
b = randn(60,1);

% Run homotopy algorithm
filename = [prefixCache,'FigTauBar2.mat'];
if ~exist(filename)
   % Set call-back option
   opts = as_setparms();
   opts.callback = @FigTauBarCallback;

   evalin('base','xHist = []; rHist = [];');
   [x,inform] = as_topy(A,b,[],opts);
   xHist = evalin('base','xHist'); rHist = evalin('base','rHist');

   % Patch history
   xHist(end+1) = 6; rHist(end+1) = 0;

   % Save data
   save(filename,'xHist','rHist');
else
   data = load(filename);
   xHist = data.xHist;
   rHist = data.rHist;
end

figure(2); clf; gca; hold on; box on;
h = plot(xHist,rHist,'r-');
ht= plot([xHist(end-1),xHist(end-1)],[0,8],'b--');
set(gca,'Fontsize',24);
set(h,'Linewidth',3);
set(ht,'LineWidth',3);
set(gca,'XTick',[],'YTick',[]);
xlim([0,6]); ylim([0,8]);

if exportFlag == 1
   ExportFigurePDF(prefixFig,'FigTauBar2.pdf');
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,'FigTauBar2.eps');
end



% ===========================================================================
function result = FigTauBarCallback(itn,x,active,svar,lambda,r,y,pObj,dObj)
% ===========================================================================
evalin('base',sprintf('xHist(end+1) = %20.15e; rHist(end+1) = %20.15e;',norm(x,1),norm(r,2)));
result = 0;

