function ExportFigureTIFF2EPS(prefix,filename)
% EXPORTFIGURETIFF2EPS   Exports figure to EPS through the TIFF format
%
%   EXPORTFIGURETIFF2EPS(PREFIX,FILENAME)  first exports the current figure
%   to the TIFF format and then converts this to an EPS file given by
%   FILENAME in the PREFIX directory. This detour is needed when exporting
%   figures with patches that use interpolated shading. When exported
%   directly to EPS interpolation is done by traversing all colors in the
%   colormap from the start to end color, rather than by interpolating
%   between the two colors directly.


% Remove .eps extension
if strcmp(lower(filename(end-3:end)),'.eps')
   basename = filename(1:end-4);
end

statusPNG  = 0;
statusTIFF = 0;
statusEPS  = 0;
result     = 0;
errmsg     = '';

p = pwd;
try
   cd(prefix);

   % -------------------------------------------------------------------
   % Save figure to cropped PNG
   % -------------------------------------------------------------------
   filenamePNG = sprintf('%s.png',basename);
   try
      ExportFigurePNG([],filename);
      statusPGN = 1;
   catch
      errmsg = sprintf('Error: Unable to export intermediate file %s', filenamePNG);
      error(errmsg);
   end
      
   
   % -------------------------------------------------------------------
   % Export plot to TIFF
   % -------------------------------------------------------------------
   filenameTIFF = sprintf('%s.tiff',basename);
   if exist(filenameTIFF,'file') ~= 0
      errmsg = sprintf('Warning: Intermediate file %s already exists', filenameTIFF);
      error(errmsg);
   end
   
   try
      img = imread(filenamePNG);
      imwrite(img,filenameTIFF,'TIFF');
      statusTIFF = 1;
   catch
      errmsg = sprintf('Error: Unable to export intermediate file %s', filenameTIFF);
      error(errmsg);
   end

   % -------------------------------------------------------------------
   % Convert TIFF to EPS
   % -------------------------------------------------------------------
   filenameEPS = sprintf('%s.eps',basename);
   [status,result] = system(sprintf('tiff2ps -e %s > %s', filenameTIFF, filenameEPS));
   if status ~= 0
      fprintf('%s\n',repmat('-',1,get(0,'CommandWindowSize')*[1;0]));
      fprintf('%s\n',result);
      fprintf('%s\n',repmat('-',1,get(0,'CommandWindowSize')*[1;0]));
      errmsg = sprintf('Error: Conversion from TIFF to EPS returned the above error');
      error(errmsg);
   end;
   statusEPS = 1;
   
   % -------------------------------------------------------------------
   % SUCCESS
   % -------------------------------------------------------------------
   result = 1;

catch
   err = lasterror;
   if ~isempty(errmsg)
      fprintf('%s\n',errmsg);
   else
      fprintf('An unexpected error occurred:\n');
      fprintf('%s\n',err.message);
   end
end

% ------------------------
% Clean up temporary files
% ------------------------
if statusTIFF
   deleteFile(filenameTIFF);
end

% -----------------------
% Return to original path
% -----------------------
cd(p);


% ----------------------------------------------------------------------
function deleteFile(filename)
% ----------------------------------------------------------------------

% Some files may not exists
if exist(filename,'file')
   try
      delete(filename);
   catch
      fprintf('Warning: Cleaning up intermediate file %s failed\n',filename);
   end
else
% Nothing
end      
