function PlotBPDNWPaper(exportFlag)

% Check export flag
if nargin < 1, exportFlag = false; end;

% Get local directory
prefix      = mfilepath(mfilename('fullpath'));
prefixFig   = [prefix,'..',filesep,'..',filesep,'fig',filesep];

% Plot runtime as function of scaling factor
sparsity     = 4;
sigmaPercent = 2;
times = zeros(3*25,20); % 3 solvers, 25 scales, 20 instances
nfuns = zeros(3*25,20); % 3 solvers, 25 scales, 20 instances

for idx = 1:20
    info = runBPDNW(20,40,sparsity,25,sigmaPercent,1,idx);
    times(:,idx) = info.tSolve(:);
    nfuns(:,idx) = info.nFuns(:);
end
times = reshape(median(times,2),3,25);
nfuns = reshape(median(nfuns,2),3,25);

figure(1); clf; gca;
h1 = plot(times');
set(h1,'LineWidth',2);
set(h1(1),'LineStyle','-.');
set(h1(2),'LineStyle','--');
set(gca,'Fontsize',24);
legend('SDPT3','SPOR-SPG','SPOR-PQN','Location','NorthWest');
xlabel('j'); ylabel('Runtime (seconds)'); set(gca,'YScale','log');

if exportFlag == 1
   ExportFigurePDF(prefixFig,sprintf('FigBPDNWPaper_Time%d.pdf',sparsity));
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,sprintf('FigBPDNWPaper_Time%d.eps',sparsity));
end

figure(2); clf; gca;
h2 = plot(nfuns(2:3,:)');
set(h2,'LineWidth',2);
set(h2(1),'Color',get(h1(2),'Color'),'LineStyle','--');
set(h2(2),'Color',get(h1(3),'Color'));
set(gca,'Fontsize',24);
legend('SPOR-SPG','SPOR-PQN','Location','NorthEast');
xlabel('j'); ylabel('Matrix products'); ylim([0,1000]);

if exportFlag == 1
   ExportFigurePDF(prefixFig,sprintf('FigBPDNWPaper_Funs%d.pdf',sparsity));
elseif exportFlag == 2
   ExportFigureEPS(prefixFig,sprintf('FigBPDNWPaper_Funs%d.eps',sparsity));
end

