function info = runBPDNW(m0,n0,sparsity,scaleMax,sigmaPercent,weightModel,idx)
% sparsity: multiplied by scaling factor i=1...scaleMax
% weightModel: 1 = 1+abs(randn(n,1));
%              2 =   abs(randn(n,1));
% idx: experiment number
% sigmaPercent: sigma as the percentage (integer) for norm of b

% Construct filename
prefix      = mfilepath(mfilename('fullpath'));
prefixCache = [prefix,'..',filesep,'cache',filesep];
filename    = sprintf('%sRunBPDNW%s_%dx%d_%d_sig%02d_no%02d.mat', prefixCache, ...
                      char('a'+weightModel-1),m0,n0,sparsity,sigmaPercent,idx);

% Load file if it exists
if exist(filename)
   s = load(filename);
   tSolve = s.tSolve;
   vSigma = s.vSigma;
   vTau   = s.vTau;
   nFuns  = s.nFuns;
   nIter  = s.nIter;

   scaleStart = s.scaleCurrent + 1;
   randn('state',s.randnState);
else
   tSolve = zeros(3,scaleMax);
   vSigma = zeros(3,scaleMax);
   vTau   = zeros(3,scaleMax);
   nFuns  = zeros(3,scaleMax);
   nIter  = zeros(3,scaleMax);

   scaleStart = 1;
   randn('state',idx+m0*n0*weightModel+16);
end

% Set up weight model
switch weightModel
   case 1
      weights = @(i) (1+abs(randn(n0*i,1)));
   case 2
      weights = @(i) abs(randn(n0*i,1));
   otherwise
      error('Unrecognized weight model.');
end

% Run, or continue experiment
for i=scaleStart:scaleMax
   cvx_precision low

   A  = randn(m0*i,n0*i);
   x0 = zeros(n0*i,1); x0(1:sparsity*i) = randn(sparsity*i,1);
   b  = A*x0 + 0.1*randn(m0*i,1);
   w  = weights(i);

   sigma = norm(b) * sigmaPercent / 100;

   [x,info] = cvx_bpdnw(A,b,w,sigma);
   tSolve(1,i) = info.time_solve;
   vSigma(1,i) = norm(A*x-b,2);
   vTau(1,i)   = norm(w.*x,1);

   options.solver = 1;
   [x,info] = gbpdn_bpdnw(A,b,w,sigma,options);
   tSolve(2,i)  = info.timeTotal;
   nFuns(2,i)  = info.nProdA + info.nProdAt;
   nIter(2,i)  = info.iter;
   vSigma(2,i) = norm(A*x-b,2);
   vTau(2,i)   = norm(w.*x,1);

   options.solver = 2;
   [x,info] = gbpdn_bpdnw(A,b,w,sigma,options);
   tSolve(3,i)  = info.timeTotal;
   nFuns(3,i)  = info.nProdA + info.nProdAt;
   nIter(3,i)  = info.iter;
   vSigma(3,i) = norm(A*x-b,2);
   vTau(3,i)   = norm(w.*x,1);

   % Save intermediate results
   randnState = randn('state');
   scaleCurrent = i;
   save(filename','tSolve','vSigma','vTau','nFuns','nIter','randnState','scaleCurrent');
end

% Generate final output structure
info = struct();
info.tSolve = tSolve(:,1:scaleMax);
info.vSigma = vSigma(:,1:scaleMax);
info.vTau   = vTau(:,1:scaleMax);
info.nFuns  = nFuns(:,1:scaleMax);
info.nIter  = nIter(:,1:scaleMax);

